
package presentacion;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

public class Opcion2 extends JPanel {
   
      private Componentes componentes;
      
    public Opcion2(Componentes componentes) {
        this.componentes = componentes;
        ubicarComponentes();
    }
     
    private void ubicarComponentes() {

        setLayout(null);        
                   // CONFIGURACIÓN JButton 
        componentes.setjButtonOpcion2(new JButton("Contar"));
        componentes.getjButtonOpcion2().setBounds(255, 220, 100, 40);  
        componentes.getjButtonOpcion2().setActionCommand("botonOpcion2");
        componentes.getjButtonOpcion2().addActionListener(componentes.getGestorEventos());   // REGISTRO DE ESCUCHA DE EVENTO DE BOTON
        add(componentes.getjButtonOpcion2());          
                   // CONFIGURACIÓN JLabel visualización contador parcial
        componentes.setjLabelParcialOpcion2(new JLabel());
        componentes.getjLabelParcialOpcion2().setBounds(100, 100, 400, 20);
        add(componentes.getjLabelParcialOpcion2()); 
                   // CONFIGURACIÓN JLabel visualización contador global
        componentes.setjLabelGlobalOpcion2(new JLabel());
        componentes.getjLabelGlobalOpcion2().setBounds(100, 150, 400, 20);
        add(componentes.getjLabelGlobalOpcion2());          
    }   
    
    public void iniciarPantalla() {
        componentes.setContadorOpcion2(0);
        componentes.getjLabelParcialOpcion2().setText("Pulsaciones botón opción 2:     "+componentes.getContadorOpcion2());
        componentes.getjLabelGlobalOpcion2().setText("Pulsaciones acumuladas de los botones de todas las opciones:     "+componentes.getContadorGlobal());        
    }    
}
